# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aiges/protocol/xsf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61iges/protocol/xsf.proto\x12\x05utils\"t\n\x07Session\x12\t\n\x01t\x18\x01 \x01(\t\x12\t\n\x01h\x18\x02 \x01(\t\x12&\n\x04sess\x18\x03 \x03(\x0b\x32\x18.utils.Session.SessEntry\x1a+\n\tSessEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x08\x44\x61taMeta\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\'\n\x04\x64\x65sc\x18\x03 \x03(\x0b\x32\x19.utils.DataMeta.DescEntry\x1a+\n\tDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x07ReqData\x12\n\n\x02op\x18\x01 \x01(\t\x12\x19\n\x01s\x18\x02 \x01(\x0b\x32\x0e.utils.Session\x12(\n\x05param\x18\x03 \x03(\x0b\x32\x19.utils.ReqData.ParamEntry\x12\x1d\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x0f.utils.DataMeta\x1a,\n\nParamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n\x07ResData\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x12\n\nerror_info\x18\x02 \x01(\t\x12\x19\n\x01s\x18\x03 \x01(\x0b\x32\x0e.utils.Session\x12(\n\x05param\x18\x04 \x03(\x0b\x32\x19.utils.ResData.ParamEntry\x12\x1d\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x0f.utils.DataMeta\x1a,\n\nParamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x07Request\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0f\n\x07headers\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\")\n\x08Response\x12\x0f\n\x07headers\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t23\n\x07XsfCall\x12(\n\x04\x63\x61ll\x12\x0e.utils.ReqData\x1a\x0e.utils.ResData\"\x00\x32\x39\n\x07ToolBox\x12.\n\tcmdserver\x12\x0e.utils.Request\x1a\x0f.utils.Response\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aiges.protocol.xsf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSION_SESSENTRY._options = None
  _SESSION_SESSENTRY._serialized_options = b'8\001'
  _DATAMETA_DESCENTRY._options = None
  _DATAMETA_DESCENTRY._serialized_options = b'8\001'
  _REQDATA_PARAMENTRY._options = None
  _REQDATA_PARAMENTRY._serialized_options = b'8\001'
  _RESDATA_PARAMENTRY._options = None
  _RESDATA_PARAMENTRY._serialized_options = b'8\001'
  _SESSION._serialized_start=35
  _SESSION._serialized_end=151
  _SESSION_SESSENTRY._serialized_start=108
  _SESSION_SESSENTRY._serialized_end=151
  _DATAMETA._serialized_start=153
  _DATAMETA._serialized_end=263
  _DATAMETA_DESCENTRY._serialized_start=220
  _DATAMETA_DESCENTRY._serialized_end=263
  _REQDATA._serialized_start=266
  _REQDATA._serialized_end=433
  _REQDATA_PARAMENTRY._serialized_start=389
  _REQDATA_PARAMENTRY._serialized_end=433
  _RESDATA._serialized_start=436
  _RESDATA._serialized_end=625
  _RESDATA_PARAMENTRY._serialized_start=389
  _RESDATA_PARAMENTRY._serialized_end=433
  _REQUEST._serialized_start=627
  _REQUEST._serialized_end=682
  _RESPONSE._serialized_start=684
  _RESPONSE._serialized_end=725
  _XSFCALL._serialized_start=727
  _XSFCALL._serialized_end=778
  _TOOLBOX._serialized_start=780
  _TOOLBOX._serialized_end=837
# @@protoc_insertion_point(module_scope)
